@@ -20,7 +20,7 @@ use OTRS::OPM::Maker -command;
 use OTRS::OPM::Maker::Utils::OTRS3;
 use OTRS::OPM::Maker::Utils::OTRS4;
 
-our $VERSION = 1.35;
+our $VERSION = 1.36;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -87,9 +87,22 @@ sub execute {
 
     {
         for my $framework ( @{ $json->{framework} } ) {
-            push @xml_parts, "    <Framework>$framework</Framework>";
+            my $version = $framework;
+            my $min     = '';
+            my $max     = '';
 
-            my $major_version = (split /\./, $framework)[0];
+            if ( 'HASH' eq ref $framework ) {
+                $version = $framework->{version};
+                $min     = $framework->{min};
+                $max     = $framework->{max};
+            }
+
+            push @xml_parts, sprintf "    <Framework%s%s>%s</Framework>",
+                ( $min ? qq~ Minimum="$min"~ : '' ),
+                ( $max ? qq~ Maximum="$max"~ : '' ),
+                $version;
+
+            my $major_version = (split /\./, $version)[0];
             $major_versions{$major_version}++;
         }
 
@@ -626,7 +639,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.35
+version 1.36
 
 =head1 DESCRIPTION
 
